summaryrefslogtreecommitdiff
path: root/sw/source/core/inc/tblrwcl.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/inc/tblrwcl.hxx')
-rw-r--r--sw/source/core/inc/tblrwcl.hxx92
1 files changed, 46 insertions, 46 deletions
diff --git a/sw/source/core/inc/tblrwcl.hxx b/sw/source/core/inc/tblrwcl.hxx
index 6100ee41a422..866e82274de9 100644
--- a/sw/source/core/inc/tblrwcl.hxx
+++ b/sw/source/core/inc/tblrwcl.hxx
@@ -50,20 +50,20 @@ class SwShareBoxFmts;
class SwFmtFrmSize;
// Funktions Deklarationen:
-BOOL lcl_CopyRow( const _FndLine*& rpFndLine, void* pPara );
-BOOL lcl_CopyCol( const _FndBox*& rpFndBox, void* pPara );
+sal_Bool lcl_CopyRow( const _FndLine*& rpFndLine, void* pPara );
+sal_Bool lcl_CopyCol( const _FndBox*& rpFndBox, void* pPara );
-BOOL lcl_MergeGCBox( const SwTableBox*& rpBox, void* pPara );
-BOOL lcl_MergeGCLine( const SwTableLine*& rpLine, void* pPara );
+sal_Bool lcl_MergeGCBox( const SwTableBox*& rpBox, void* pPara );
+sal_Bool lcl_MergeGCLine( const SwTableLine*& rpLine, void* pPara );
-BOOL lcl_Merge_MoveBox( const _FndBox*& rpFndBox, void* pPara );
-BOOL lcl_Merge_MoveLine( const _FndLine*& rpFndLine, void* pPara );
+sal_Bool lcl_Merge_MoveBox( const _FndBox*& rpFndBox, void* pPara );
+sal_Bool lcl_Merge_MoveLine( const _FndLine*& rpFndLine, void* pPara );
-BOOL lcl_CopyBoxToDoc( const _FndBox*& rpFndBox, void* pPara );
-BOOL lcl_CopyLineToDoc( const _FndLine*& rpFndLn, void* pPara );
+sal_Bool lcl_CopyBoxToDoc( const _FndBox*& rpFndBox, void* pPara );
+sal_Bool lcl_CopyLineToDoc( const _FndLine*& rpFndLn, void* pPara );
-BOOL lcl_BoxSetHeadCondColl( const SwTableBox*& rpBox, void* pPara );
-BOOL lcl_LineSetHeadCondColl( const SwTableLine*& rpLine, void* pPara );
+sal_Bool lcl_BoxSetHeadCondColl( const SwTableBox*& rpBox, void* pPara );
+sal_Bool lcl_LineSetHeadCondColl( const SwTableLine*& rpLine, void* pPara );
#ifdef DBG_UTIL
@@ -72,10 +72,10 @@ void _CheckBoxWidth( const SwTableLine& rLine, SwTwips nSize );
void _InsTblBox( SwDoc* pDoc, SwTableNode* pTblNd,
SwTableLine* pLine, SwTableBoxFmt* pBoxFrmFmt,
- SwTableBox* pBox, USHORT nInsPos, USHORT nCnt = 1 );
+ SwTableBox* pBox, sal_uInt16 nInsPos, sal_uInt16 nCnt = 1 );
SW_DLLPUBLIC void _DeleteBox( SwTable& rTbl, SwTableBox* pBox, SwUndo* pUndo = 0,
- BOOL bCalcNewSize = TRUE, const BOOL bCorrBorder = TRUE,
+ sal_Bool bCalcNewSize = sal_True, const sal_Bool bCorrBorder = sal_True,
SwShareBoxFmts* pShareFmts = 0 );
// Klasse fuers SplitTable
@@ -88,15 +88,15 @@ class SwCollectTblLineBoxes
SvUShorts aPosArr;
SwSelBoxes_SAR aBoxes;
SwHistory* pHst;
- USHORT nMode, nWidth;
- BOOL bGetFromTop : 1;
- BOOL bGetValues : 1;
+ sal_uInt16 nMode, nWidth;
+ sal_Bool bGetFromTop : 1;
+ sal_Bool bGetValues : 1;
public:
- SwCollectTblLineBoxes( BOOL bTop, USHORT nMd = 0, SwHistory* pHist=0 )
+ SwCollectTblLineBoxes( sal_Bool bTop, sal_uInt16 nMd = 0, SwHistory* pHist=0 )
: aPosArr( 16, 16 ), aBoxes( 16, 16 ),
pHst( pHist ), nMode( nMd ), nWidth( 0 ),
- bGetFromTop( bTop ), bGetValues( TRUE )
+ bGetFromTop( bTop ), bGetValues( sal_True )
{}
@@ -104,8 +104,8 @@ public:
const SwTableBox* GetBoxOfPos( const SwTableBox& rBox );
void AddToUndoHistory( const SwCntntNode& rNd );
- USHORT Count() const { return aBoxes.Count(); }
- const SwTableBox& GetBox( USHORT nPos, USHORT* pWidth = 0 ) const
+ sal_uInt16 Count() const { return aBoxes.Count(); }
+ const SwTableBox& GetBox( sal_uInt16 nPos, sal_uInt16* pWidth = 0 ) const
{
// hier wird die EndPos der Spalte benoetigt!
if( pWidth )
@@ -114,68 +114,68 @@ public:
return *aBoxes[ nPos ];
}
- BOOL IsGetFromTop() const { return bGetFromTop; }
- BOOL IsGetValues() const { return bGetValues; }
+ sal_Bool IsGetFromTop() const { return bGetFromTop; }
+ sal_Bool IsGetValues() const { return bGetValues; }
- USHORT GetMode() const { return nMode; }
- void SetValues( BOOL bFlag ) { bGetValues = FALSE; nWidth = 0;
+ sal_uInt16 GetMode() const { return nMode; }
+ void SetValues( sal_Bool bFlag ) { bGetValues = sal_False; nWidth = 0;
bGetFromTop = bFlag; }
- BOOL Resize( USHORT nOffset, USHORT nWidth );
+ sal_Bool Resize( sal_uInt16 nOffset, sal_uInt16 nWidth );
};
-BOOL lcl_Box_CollectBox( const SwTableBox*& rpBox, void* pPara );
-BOOL lcl_Line_CollectBox( const SwTableLine*& rpLine, void* pPara );
+sal_Bool lcl_Box_CollectBox( const SwTableBox*& rpBox, void* pPara );
+sal_Bool lcl_Line_CollectBox( const SwTableLine*& rpLine, void* pPara );
-BOOL lcl_BoxSetSplitBoxFmts( const SwTableBox*& rpBox, void* pPara );
+sal_Bool lcl_BoxSetSplitBoxFmts( const SwTableBox*& rpBox, void* pPara );
// This structure is needed by Undo to restore row span attributes
// when a table has been splitted into two tables
struct SwSaveRowSpan
{
- USHORT mnSplitLine; // the line number where the table has been splitted
+ sal_uInt16 mnSplitLine; // the line number where the table has been splitted
std::vector< long > mnRowSpans; // the row span attributes in this line
- SwSaveRowSpan( SwTableBoxes& rBoxes, USHORT nSplitLn );
+ SwSaveRowSpan( SwTableBoxes& rBoxes, sal_uInt16 nSplitLn );
};
struct _SwGCLineBorder
{
const SwTableLines* pLines;
SwShareBoxFmts* pShareFmts;
- USHORT nLinePos;
+ sal_uInt16 nLinePos;
_SwGCLineBorder( const SwTable& rTable )
: pLines( &rTable.GetTabLines() ), pShareFmts(0), nLinePos( 0 ) {}
_SwGCLineBorder( const SwTableBox& rBox )
: pLines( &rBox.GetTabLines() ), pShareFmts(0), nLinePos( 0 ) {}
- BOOL IsLastLine() const { return nLinePos + 1 >= pLines->Count(); }
+ sal_Bool IsLastLine() const { return nLinePos + 1 >= pLines->Count(); }
};
class _SwGCBorder_BoxBrd
{
const SvxBorderLine* pBrdLn;
- BOOL bAnyBorderFnd;
+ sal_Bool bAnyBorderFnd;
public:
- _SwGCBorder_BoxBrd() : pBrdLn( 0 ), bAnyBorderFnd( FALSE ) {}
+ _SwGCBorder_BoxBrd() : pBrdLn( 0 ), bAnyBorderFnd( sal_False ) {}
void SetBorder( const SvxBorderLine& rBorderLine )
- { pBrdLn = &rBorderLine; bAnyBorderFnd = FALSE; }
+ { pBrdLn = &rBorderLine; bAnyBorderFnd = sal_False; }
// checke, ob die linke Border dieselbe wie die gesetzte ist
- // returnt FALSE falls gar keine Border gesetzt ist
- BOOL CheckLeftBorderOfFormat( const SwFrmFmt& rFmt );
+ // returnt sal_False falls gar keine Border gesetzt ist
+ sal_Bool CheckLeftBorderOfFormat( const SwFrmFmt& rFmt );
- BOOL IsAnyBorderFound() const { return bAnyBorderFnd; }
+ sal_Bool IsAnyBorderFound() const { return bAnyBorderFnd; }
};
-BOOL lcl_GC_Line_Border( const SwTableLine*& , void* pPara );
-BOOL lcl_GC_Box_Border( const SwTableBox*& , void* pPara );
+sal_Bool lcl_GC_Line_Border( const SwTableLine*& , void* pPara );
+sal_Bool lcl_GC_Box_Border( const SwTableBox*& , void* pPara );
-BOOL lcl_GCBorder_ChkBoxBrd_L( const SwTableLine*& , void* pPara );
-BOOL lcl_GCBorder_ChkBoxBrd_B( const SwTableBox*& , void* pPara );
+sal_Bool lcl_GCBorder_ChkBoxBrd_L( const SwTableLine*& , void* pPara );
+sal_Bool lcl_GCBorder_ChkBoxBrd_B( const SwTableBox*& , void* pPara );
-BOOL lcl_GCBorder_GetLastBox_L( const SwTableLine*& , void* pPara );
-BOOL lcl_GCBorder_GetLastBox_B( const SwTableBox*& , void* pPara );
+sal_Bool lcl_GCBorder_GetLastBox_L( const SwTableLine*& , void* pPara );
+sal_Bool lcl_GCBorder_GetLastBox_B( const SwTableBox*& , void* pPara );
class SwShareBoxFmt
@@ -193,8 +193,8 @@ public:
SwFrmFmt* GetFormat( long nWidth ) const;
SwFrmFmt* GetFormat( const SfxPoolItem& rItem ) const;
void AddFormat( const SwFrmFmt& rFmt );
- // returnt TRUE, wenn geloescht werden kann
- BOOL RemoveFormat( const SwFrmFmt& rFmt );
+ // returnt sal_True, wenn geloescht werden kann
+ sal_Bool RemoveFormat( const SwFrmFmt& rFmt );
};
@@ -203,7 +203,7 @@ SV_DECL_PTRARR_DEL( _SwShareBoxFmts, SwShareBoxFmt*, 8, 8 )
class SwShareBoxFmts
{
_SwShareBoxFmts aShareArr;
- BOOL Seek_Entry( const SwFrmFmt& rFmt, USHORT* pPos ) const;
+ sal_Bool Seek_Entry( const SwFrmFmt& rFmt, sal_uInt16* pPos ) const;
void ChangeFrmFmt( SwTableBox* pBox, SwTableLine* pLn, SwFrmFmt& rFmt );